``zodburi``
===========

A library which parses URIs and converts them to ZODB storage objects and
database arguments.

See the documentation at http://docs.pylonsproject.org/projects/zodburi/dev/
for more information.

